# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
ChFiDS module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_chfids.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _ChFiDS
else:
    import _ChFiDS

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _ChFiDS.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _ChFiDS.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ChFiDS.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ChFiDS.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _ChFiDS.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _ChFiDS.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _ChFiDS.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _ChFiDS.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _ChFiDS.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _ChFiDS.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ChFiDS.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _ChFiDS.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _ChFiDS.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ChFiDS.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ChFiDS.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ChFiDS.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _ChFiDS.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _ChFiDS:
_ChFiDS.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _ChFiDS.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.TopTools
import OCC.Core.BRepAdaptor
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor
import OCC.Core.Law

from enum import IntEnum
from OCC.Core.Exception import *

ChFiDS_OnSame = _ChFiDS.ChFiDS_OnSame
ChFiDS_OnDiff = _ChFiDS.ChFiDS_OnDiff
ChFiDS_AllSame = _ChFiDS.ChFiDS_AllSame
ChFiDS_BreakPoint = _ChFiDS.ChFiDS_BreakPoint
ChFiDS_FreeBoundary = _ChFiDS.ChFiDS_FreeBoundary
ChFiDS_Closed = _ChFiDS.ChFiDS_Closed
ChFiDS_Tangent = _ChFiDS.ChFiDS_Tangent
ChFiDS_Sym = _ChFiDS.ChFiDS_Sym
ChFiDS_TwoDist = _ChFiDS.ChFiDS_TwoDist
ChFiDS_DistAngle = _ChFiDS.ChFiDS_DistAngle
ChFiDS_ClassicChamfer = _ChFiDS.ChFiDS_ClassicChamfer
ChFiDS_ConstThroatChamfer = _ChFiDS.ChFiDS_ConstThroatChamfer
ChFiDS_ConstThroatWithPenetrationChamfer = _ChFiDS.ChFiDS_ConstThroatWithPenetrationChamfer
ChFiDS_Ok = _ChFiDS.ChFiDS_Ok
ChFiDS_Error = _ChFiDS.ChFiDS_Error
ChFiDS_WalkingFailure = _ChFiDS.ChFiDS_WalkingFailure
ChFiDS_StartsolFailure = _ChFiDS.ChFiDS_StartsolFailure
ChFiDS_TwistedSurface = _ChFiDS.ChFiDS_TwistedSurface
ChFiDS_Concave = _ChFiDS.ChFiDS_Concave
ChFiDS_Convex = _ChFiDS.ChFiDS_Convex
ChFiDS_Tangential = _ChFiDS.ChFiDS_Tangential
ChFiDS_FreeBound = _ChFiDS.ChFiDS_FreeBound
ChFiDS_Other = _ChFiDS.ChFiDS_Other


class ChFiDS_State(IntEnum):
	ChFiDS_OnSame = 0
	ChFiDS_OnDiff = 1
	ChFiDS_AllSame = 2
	ChFiDS_BreakPoint = 3
	ChFiDS_FreeBoundary = 4
	ChFiDS_Closed = 5
	ChFiDS_Tangent = 6
ChFiDS_OnSame = ChFiDS_State.ChFiDS_OnSame
ChFiDS_OnDiff = ChFiDS_State.ChFiDS_OnDiff
ChFiDS_AllSame = ChFiDS_State.ChFiDS_AllSame
ChFiDS_BreakPoint = ChFiDS_State.ChFiDS_BreakPoint
ChFiDS_FreeBoundary = ChFiDS_State.ChFiDS_FreeBoundary
ChFiDS_Closed = ChFiDS_State.ChFiDS_Closed
ChFiDS_Tangent = ChFiDS_State.ChFiDS_Tangent

class ChFiDS_ChamfMethod(IntEnum):
	ChFiDS_Sym = 0
	ChFiDS_TwoDist = 1
	ChFiDS_DistAngle = 2
ChFiDS_Sym = ChFiDS_ChamfMethod.ChFiDS_Sym
ChFiDS_TwoDist = ChFiDS_ChamfMethod.ChFiDS_TwoDist
ChFiDS_DistAngle = ChFiDS_ChamfMethod.ChFiDS_DistAngle

class ChFiDS_ChamfMode(IntEnum):
	ChFiDS_ClassicChamfer = 0
	ChFiDS_ConstThroatChamfer = 1
	ChFiDS_ConstThroatWithPenetrationChamfer = 2
ChFiDS_ClassicChamfer = ChFiDS_ChamfMode.ChFiDS_ClassicChamfer
ChFiDS_ConstThroatChamfer = ChFiDS_ChamfMode.ChFiDS_ConstThroatChamfer
ChFiDS_ConstThroatWithPenetrationChamfer = ChFiDS_ChamfMode.ChFiDS_ConstThroatWithPenetrationChamfer

class ChFiDS_ErrorStatus(IntEnum):
	ChFiDS_Ok = 0
	ChFiDS_Error = 1
	ChFiDS_WalkingFailure = 2
	ChFiDS_StartsolFailure = 3
	ChFiDS_TwistedSurface = 4
ChFiDS_Ok = ChFiDS_ErrorStatus.ChFiDS_Ok
ChFiDS_Error = ChFiDS_ErrorStatus.ChFiDS_Error
ChFiDS_WalkingFailure = ChFiDS_ErrorStatus.ChFiDS_WalkingFailure
ChFiDS_StartsolFailure = ChFiDS_ErrorStatus.ChFiDS_StartsolFailure
ChFiDS_TwistedSurface = ChFiDS_ErrorStatus.ChFiDS_TwistedSurface

class ChFiDS_TypeOfConcavity(IntEnum):
	ChFiDS_Concave = 0
	ChFiDS_Convex = 1
	ChFiDS_Tangential = 2
	ChFiDS_FreeBound = 3
	ChFiDS_Other = 4
ChFiDS_Concave = ChFiDS_TypeOfConcavity.ChFiDS_Concave
ChFiDS_Convex = ChFiDS_TypeOfConcavity.ChFiDS_Convex
ChFiDS_Tangential = ChFiDS_TypeOfConcavity.ChFiDS_Tangential
ChFiDS_FreeBound = ChFiDS_TypeOfConcavity.ChFiDS_FreeBound
ChFiDS_Other = ChFiDS_TypeOfConcavity.ChFiDS_Other


def Handle_ChFiDS_HElSpine_Create() -> "opencascade::handle< ChFiDS_HElSpine >":
    return _ChFiDS.Handle_ChFiDS_HElSpine_Create()

def Handle_ChFiDS_HElSpine_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ChFiDS_HElSpine >":
    return _ChFiDS.Handle_ChFiDS_HElSpine_DownCast(t)

def Handle_ChFiDS_HElSpine_IsNull(t: "opencascade::handle< ChFiDS_HElSpine > const &") -> "bool":
    return _ChFiDS.Handle_ChFiDS_HElSpine_IsNull(t)

def Handle_ChFiDS_Spine_Create() -> "opencascade::handle< ChFiDS_Spine >":
    return _ChFiDS.Handle_ChFiDS_Spine_Create()

def Handle_ChFiDS_Spine_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ChFiDS_Spine >":
    return _ChFiDS.Handle_ChFiDS_Spine_DownCast(t)

def Handle_ChFiDS_Spine_IsNull(t: "opencascade::handle< ChFiDS_Spine > const &") -> "bool":
    return _ChFiDS.Handle_ChFiDS_Spine_IsNull(t)

def Handle_ChFiDS_Stripe_Create() -> "opencascade::handle< ChFiDS_Stripe >":
    return _ChFiDS.Handle_ChFiDS_Stripe_Create()

def Handle_ChFiDS_Stripe_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ChFiDS_Stripe >":
    return _ChFiDS.Handle_ChFiDS_Stripe_DownCast(t)

def Handle_ChFiDS_Stripe_IsNull(t: "opencascade::handle< ChFiDS_Stripe > const &") -> "bool":
    return _ChFiDS.Handle_ChFiDS_Stripe_IsNull(t)

def Handle_ChFiDS_SurfData_Create() -> "opencascade::handle< ChFiDS_SurfData >":
    return _ChFiDS.Handle_ChFiDS_SurfData_Create()

def Handle_ChFiDS_SurfData_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ChFiDS_SurfData >":
    return _ChFiDS.Handle_ChFiDS_SurfData_DownCast(t)

def Handle_ChFiDS_SurfData_IsNull(t: "opencascade::handle< ChFiDS_SurfData > const &") -> "bool":
    return _ChFiDS.Handle_ChFiDS_SurfData_IsNull(t)

def Handle_ChFiDS_ChamfSpine_Create() -> "opencascade::handle< ChFiDS_ChamfSpine >":
    return _ChFiDS.Handle_ChFiDS_ChamfSpine_Create()

def Handle_ChFiDS_ChamfSpine_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ChFiDS_ChamfSpine >":
    return _ChFiDS.Handle_ChFiDS_ChamfSpine_DownCast(t)

def Handle_ChFiDS_ChamfSpine_IsNull(t: "opencascade::handle< ChFiDS_ChamfSpine > const &") -> "bool":
    return _ChFiDS.Handle_ChFiDS_ChamfSpine_IsNull(t)

def Handle_ChFiDS_FilSpine_Create() -> "opencascade::handle< ChFiDS_FilSpine >":
    return _ChFiDS.Handle_ChFiDS_FilSpine_Create()

def Handle_ChFiDS_FilSpine_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ChFiDS_FilSpine >":
    return _ChFiDS.Handle_ChFiDS_FilSpine_DownCast(t)

def Handle_ChFiDS_FilSpine_IsNull(t: "opencascade::handle< ChFiDS_FilSpine > const &") -> "bool":
    return _ChFiDS.Handle_ChFiDS_FilSpine_IsNull(t)

def Handle_ChFiDS_SecHArray1_Create() -> "opencascade::handle< ChFiDS_SecHArray1 >":
    return _ChFiDS.Handle_ChFiDS_SecHArray1_Create()

def Handle_ChFiDS_SecHArray1_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ChFiDS_SecHArray1 >":
    return _ChFiDS.Handle_ChFiDS_SecHArray1_DownCast(t)

def Handle_ChFiDS_SecHArray1_IsNull(t: "opencascade::handle< ChFiDS_SecHArray1 > const &") -> "bool":
    return _ChFiDS.Handle_ChFiDS_SecHArray1_IsNull(t)

def Handle_ChFiDS_HData_Create() -> "opencascade::handle< ChFiDS_HData >":
    return _ChFiDS.Handle_ChFiDS_HData_Create()

def Handle_ChFiDS_HData_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ChFiDS_HData >":
    return _ChFiDS.Handle_ChFiDS_HData_DownCast(t)

def Handle_ChFiDS_HData_IsNull(t: "opencascade::handle< ChFiDS_HData > const &") -> "bool":
    return _ChFiDS.Handle_ChFiDS_HData_IsNull(t)
class ChFiDS_IndexedDataMapOfVertexListOfStripe(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_IndexedDataMap< TopoDS_Vertex,ChFiDS_ListOfStripe,TopTools_ShapeMapHasher >::iterator":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_begin(self)

    def end(self) -> "NCollection_IndexedDataMap< TopoDS_Vertex,ChFiDS_ListOfStripe,TopTools_ShapeMapHasher >::iterator":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_end(self)

    def cbegin(self) -> "NCollection_IndexedDataMap< TopoDS_Vertex,ChFiDS_ListOfStripe,TopTools_ShapeMapHasher >::const_iterator":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_cbegin(self)

    def cend(self) -> "NCollection_IndexedDataMap< TopoDS_Vertex,ChFiDS_ListOfStripe,TopTools_ShapeMapHasher >::const_iterator":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_cend(self)

    def __init__(self, *args):
        _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_swiginit(self, _ChFiDS.new_ChFiDS_IndexedDataMapOfVertexListOfStripe(*args))

    def Exchange(self, theOther: "ChFiDS_IndexedDataMapOfVertexListOfStripe") -> "void":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_Exchange(self, theOther)

    def Assign(self, theOther: "ChFiDS_IndexedDataMapOfVertexListOfStripe") -> "NCollection_IndexedDataMap< TopoDS_Vertex,ChFiDS_ListOfStripe,TopTools_ShapeMapHasher > &":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_Assign(self, theOther)

    def Set(self, theOther: "ChFiDS_IndexedDataMapOfVertexListOfStripe") -> "NCollection_IndexedDataMap< TopoDS_Vertex,ChFiDS_ListOfStripe,TopTools_ShapeMapHasher > &":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_ReSize(self, N)

    def Add(self, theKey1: "TopoDS_Vertex", theItem: "ChFiDS_ListOfStripe") -> "Standard_Integer":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_Add(self, theKey1, theItem)

    def Contains(self, theKey1: "TopoDS_Vertex") -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_Contains(self, theKey1)

    def Substitute(self, theIndex: "Standard_Integer const", theKey1: "TopoDS_Vertex", theItem: "ChFiDS_ListOfStripe") -> "void":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_Substitute(self, theIndex, theKey1, theItem)

    def Swap(self, theIndex1: "Standard_Integer const", theIndex2: "Standard_Integer const") -> "void":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_Swap(self, theIndex1, theIndex2)

    def RemoveLast(self) -> "void":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_RemoveLast(self)

    def RemoveFromIndex(self, theIndex: "Standard_Integer const") -> "void":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_RemoveFromIndex(self, theIndex)

    def RemoveKey(self, theKey1: "TopoDS_Vertex") -> "void":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_RemoveKey(self, theKey1)

    def FindKey(self, theIndex: "Standard_Integer const") -> "TopoDS_Vertex const &":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_FindKey(self, theIndex)

    def FindFromIndex(self, theIndex: "Standard_Integer const") -> "ChFiDS_ListOfStripe const &":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_FindFromIndex(self, theIndex)

    def ChangeFromIndex(self, theIndex: "Standard_Integer const") -> "ChFiDS_ListOfStripe &":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_ChangeFromIndex(self, theIndex)

    def __call__(self, *args) -> "ChFiDS_ListOfStripe &":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe___call__(self, *args)

    def FindIndex(self, theKey1: "TopoDS_Vertex") -> "Standard_Integer":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_FindIndex(self, theKey1)

    def ChangeFromKey(self, theKey1: "TopoDS_Vertex") -> "ChFiDS_ListOfStripe &":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_ChangeFromKey(self, theKey1)

    def Seek(self, theKey1: "TopoDS_Vertex") -> "ChFiDS_ListOfStripe const *":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_Seek(self, theKey1)

    def ChangeSeek(self, theKey1: "TopoDS_Vertex") -> "ChFiDS_ListOfStripe *":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_ChangeSeek(self, theKey1)

    def FindFromKey(self, *args) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_FindFromKey(self, *args)

    def Clear(self, *args) -> "void":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_Clear(self, *args)
    __swig_destroy__ = _ChFiDS.delete_ChFiDS_IndexedDataMapOfVertexListOfStripe

    def Size(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_Size(self)

# Register ChFiDS_IndexedDataMapOfVertexListOfStripe in _ChFiDS:
_ChFiDS.ChFiDS_IndexedDataMapOfVertexListOfStripe_swigregister(ChFiDS_IndexedDataMapOfVertexListOfStripe)

class ChFiDS_ListIteratorOfListOfHElSpine(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _ChFiDS.ChFiDS_ListIteratorOfListOfHElSpine_swiginit(self, _ChFiDS.new_ChFiDS_ListIteratorOfListOfHElSpine(*args))

    def More(self) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_ListIteratorOfListOfHElSpine_More(self)

    def Next(self) -> "void":
        return _ChFiDS.ChFiDS_ListIteratorOfListOfHElSpine_Next(self)

    def Value(self) -> "opencascade::handle< ChFiDS_HElSpine > const &":
        return _ChFiDS.ChFiDS_ListIteratorOfListOfHElSpine_Value(self)

    def ChangeValue(self) -> "opencascade::handle< ChFiDS_HElSpine > &":
        return _ChFiDS.ChFiDS_ListIteratorOfListOfHElSpine_ChangeValue(self)
    __swig_destroy__ = _ChFiDS.delete_ChFiDS_ListIteratorOfListOfHElSpine

# Register ChFiDS_ListIteratorOfListOfHElSpine in _ChFiDS:
_ChFiDS.ChFiDS_ListIteratorOfListOfHElSpine_swigregister(ChFiDS_ListIteratorOfListOfHElSpine)

class ChFiDS_ListIteratorOfListOfStripe(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _ChFiDS.ChFiDS_ListIteratorOfListOfStripe_swiginit(self, _ChFiDS.new_ChFiDS_ListIteratorOfListOfStripe(*args))

    def More(self) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_ListIteratorOfListOfStripe_More(self)

    def Next(self) -> "void":
        return _ChFiDS.ChFiDS_ListIteratorOfListOfStripe_Next(self)

    def Value(self) -> "opencascade::handle< ChFiDS_Stripe > const &":
        return _ChFiDS.ChFiDS_ListIteratorOfListOfStripe_Value(self)

    def ChangeValue(self) -> "opencascade::handle< ChFiDS_Stripe > &":
        return _ChFiDS.ChFiDS_ListIteratorOfListOfStripe_ChangeValue(self)
    __swig_destroy__ = _ChFiDS.delete_ChFiDS_ListIteratorOfListOfStripe

# Register ChFiDS_ListIteratorOfListOfStripe in _ChFiDS:
_ChFiDS.ChFiDS_ListIteratorOfListOfStripe_swigregister(ChFiDS_ListIteratorOfListOfStripe)

class ChFiDS_ListIteratorOfRegularities(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _ChFiDS.ChFiDS_ListIteratorOfRegularities_swiginit(self, _ChFiDS.new_ChFiDS_ListIteratorOfRegularities(*args))

    def More(self) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_ListIteratorOfRegularities_More(self)

    def Next(self) -> "void":
        return _ChFiDS.ChFiDS_ListIteratorOfRegularities_Next(self)

    def Value(self) -> "ChFiDS_Regul const &":
        return _ChFiDS.ChFiDS_ListIteratorOfRegularities_Value(self)

    def ChangeValue(self) -> "ChFiDS_Regul &":
        return _ChFiDS.ChFiDS_ListIteratorOfRegularities_ChangeValue(self)
    __swig_destroy__ = _ChFiDS.delete_ChFiDS_ListIteratorOfRegularities

# Register ChFiDS_ListIteratorOfRegularities in _ChFiDS:
_ChFiDS.ChFiDS_ListIteratorOfRegularities_swigregister(ChFiDS_ListIteratorOfRegularities)

class ChFiDS_ListOfHElSpine(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< opencascade::handle< ChFiDS_HElSpine > >::iterator":
        return _ChFiDS.ChFiDS_ListOfHElSpine_begin(self)

    def end(self) -> "NCollection_List< opencascade::handle< ChFiDS_HElSpine > >::iterator":
        return _ChFiDS.ChFiDS_ListOfHElSpine_end(self)

    def cbegin(self) -> "NCollection_List< opencascade::handle< ChFiDS_HElSpine > >::const_iterator":
        return _ChFiDS.ChFiDS_ListOfHElSpine_cbegin(self)

    def cend(self) -> "NCollection_List< opencascade::handle< ChFiDS_HElSpine > >::const_iterator":
        return _ChFiDS.ChFiDS_ListOfHElSpine_cend(self)

    def __init__(self, *args):
        _ChFiDS.ChFiDS_ListOfHElSpine_swiginit(self, _ChFiDS.new_ChFiDS_ListOfHElSpine(*args))

    def Size(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_ListOfHElSpine_Size(self)

    def Assign(self, theOther: "ChFiDS_ListOfHElSpine") -> "NCollection_List< opencascade::handle< ChFiDS_HElSpine > > &":
        return _ChFiDS.ChFiDS_ListOfHElSpine_Assign(self, theOther)

    def Set(self, theOther: "ChFiDS_ListOfHElSpine") -> "NCollection_List< opencascade::handle< ChFiDS_HElSpine > > &":
        return _ChFiDS.ChFiDS_ListOfHElSpine_Set(self, theOther)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _ChFiDS.ChFiDS_ListOfHElSpine_Clear(self, theAllocator)

    def First(self) -> "opencascade::handle< ChFiDS_HElSpine > const &":
        return _ChFiDS.ChFiDS_ListOfHElSpine_First(self)

    def Last(self) -> "opencascade::handle< ChFiDS_HElSpine > const &":
        return _ChFiDS.ChFiDS_ListOfHElSpine_Last(self)

    def Append(self, *args) -> "void":
        return _ChFiDS.ChFiDS_ListOfHElSpine_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _ChFiDS.ChFiDS_ListOfHElSpine_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _ChFiDS.ChFiDS_ListOfHElSpine_RemoveFirst(self)

    def Remove(self, theIter: "ChFiDS_ListIteratorOfListOfHElSpine") -> "void":
        return _ChFiDS.ChFiDS_ListOfHElSpine_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _ChFiDS.ChFiDS_ListOfHElSpine_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _ChFiDS.ChFiDS_ListOfHElSpine_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _ChFiDS.ChFiDS_ListOfHElSpine_Reverse(self)
    __swig_destroy__ = _ChFiDS.delete_ChFiDS_ListOfHElSpine

    def __len__(self):
        return self.Size()


# Register ChFiDS_ListOfHElSpine in _ChFiDS:
_ChFiDS.ChFiDS_ListOfHElSpine_swigregister(ChFiDS_ListOfHElSpine)

class ChFiDS_ListOfStripe(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< opencascade::handle< ChFiDS_Stripe > >::iterator":
        return _ChFiDS.ChFiDS_ListOfStripe_begin(self)

    def end(self) -> "NCollection_List< opencascade::handle< ChFiDS_Stripe > >::iterator":
        return _ChFiDS.ChFiDS_ListOfStripe_end(self)

    def cbegin(self) -> "NCollection_List< opencascade::handle< ChFiDS_Stripe > >::const_iterator":
        return _ChFiDS.ChFiDS_ListOfStripe_cbegin(self)

    def cend(self) -> "NCollection_List< opencascade::handle< ChFiDS_Stripe > >::const_iterator":
        return _ChFiDS.ChFiDS_ListOfStripe_cend(self)

    def __init__(self, *args):
        _ChFiDS.ChFiDS_ListOfStripe_swiginit(self, _ChFiDS.new_ChFiDS_ListOfStripe(*args))

    def Size(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_ListOfStripe_Size(self)

    def Assign(self, theOther: "ChFiDS_ListOfStripe") -> "NCollection_List< opencascade::handle< ChFiDS_Stripe > > &":
        return _ChFiDS.ChFiDS_ListOfStripe_Assign(self, theOther)

    def Set(self, theOther: "ChFiDS_ListOfStripe") -> "NCollection_List< opencascade::handle< ChFiDS_Stripe > > &":
        return _ChFiDS.ChFiDS_ListOfStripe_Set(self, theOther)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _ChFiDS.ChFiDS_ListOfStripe_Clear(self, theAllocator)

    def First(self) -> "opencascade::handle< ChFiDS_Stripe > const &":
        return _ChFiDS.ChFiDS_ListOfStripe_First(self)

    def Last(self) -> "opencascade::handle< ChFiDS_Stripe > const &":
        return _ChFiDS.ChFiDS_ListOfStripe_Last(self)

    def Append(self, *args) -> "void":
        return _ChFiDS.ChFiDS_ListOfStripe_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _ChFiDS.ChFiDS_ListOfStripe_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _ChFiDS.ChFiDS_ListOfStripe_RemoveFirst(self)

    def Remove(self, theIter: "ChFiDS_ListIteratorOfListOfStripe") -> "void":
        return _ChFiDS.ChFiDS_ListOfStripe_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _ChFiDS.ChFiDS_ListOfStripe_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _ChFiDS.ChFiDS_ListOfStripe_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _ChFiDS.ChFiDS_ListOfStripe_Reverse(self)
    __swig_destroy__ = _ChFiDS.delete_ChFiDS_ListOfStripe

    def __len__(self):
        return self.Size()


# Register ChFiDS_ListOfStripe in _ChFiDS:
_ChFiDS.ChFiDS_ListOfStripe_swigregister(ChFiDS_ListOfStripe)

class ChFiDS_Regularities(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< ChFiDS_Regul >::iterator":
        return _ChFiDS.ChFiDS_Regularities_begin(self)

    def end(self) -> "NCollection_List< ChFiDS_Regul >::iterator":
        return _ChFiDS.ChFiDS_Regularities_end(self)

    def cbegin(self) -> "NCollection_List< ChFiDS_Regul >::const_iterator":
        return _ChFiDS.ChFiDS_Regularities_cbegin(self)

    def cend(self) -> "NCollection_List< ChFiDS_Regul >::const_iterator":
        return _ChFiDS.ChFiDS_Regularities_cend(self)

    def __init__(self, *args):
        _ChFiDS.ChFiDS_Regularities_swiginit(self, _ChFiDS.new_ChFiDS_Regularities(*args))

    def Size(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_Regularities_Size(self)

    def Assign(self, theOther: "ChFiDS_Regularities") -> "NCollection_List< ChFiDS_Regul > &":
        return _ChFiDS.ChFiDS_Regularities_Assign(self, theOther)

    def Set(self, theOther: "ChFiDS_Regularities") -> "NCollection_List< ChFiDS_Regul > &":
        return _ChFiDS.ChFiDS_Regularities_Set(self, theOther)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _ChFiDS.ChFiDS_Regularities_Clear(self, theAllocator)

    def First(self) -> "ChFiDS_Regul const &":
        return _ChFiDS.ChFiDS_Regularities_First(self)

    def Last(self) -> "ChFiDS_Regul const &":
        return _ChFiDS.ChFiDS_Regularities_Last(self)

    def Append(self, *args) -> "void":
        return _ChFiDS.ChFiDS_Regularities_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _ChFiDS.ChFiDS_Regularities_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _ChFiDS.ChFiDS_Regularities_RemoveFirst(self)

    def Remove(self, theIter: "ChFiDS_ListIteratorOfRegularities") -> "void":
        return _ChFiDS.ChFiDS_Regularities_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _ChFiDS.ChFiDS_Regularities_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _ChFiDS.ChFiDS_Regularities_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _ChFiDS.ChFiDS_Regularities_Reverse(self)
    __swig_destroy__ = _ChFiDS.delete_ChFiDS_Regularities

    def __len__(self):
        return self.Size()


# Register ChFiDS_Regularities in _ChFiDS:
_ChFiDS.ChFiDS_Regularities_swigregister(ChFiDS_Regularities)

class ChFiDS_SecArray1(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< ChFiDS_CircSection >::iterator":
        return _ChFiDS.ChFiDS_SecArray1_begin(self)

    def end(self) -> "NCollection_Array1< ChFiDS_CircSection >::iterator":
        return _ChFiDS.ChFiDS_SecArray1_end(self)

    def cbegin(self) -> "NCollection_Array1< ChFiDS_CircSection >::const_iterator":
        return _ChFiDS.ChFiDS_SecArray1_cbegin(self)

    def cend(self) -> "NCollection_Array1< ChFiDS_CircSection >::const_iterator":
        return _ChFiDS.ChFiDS_SecArray1_cend(self)

    def __init__(self, *args):
        _ChFiDS.ChFiDS_SecArray1_swiginit(self, _ChFiDS.new_ChFiDS_SecArray1(*args))

    def Init(self, theValue: "ChFiDS_CircSection") -> "void":
        return _ChFiDS.ChFiDS_SecArray1_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SecArray1_Size(self)

    def Length(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SecArray1_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_SecArray1_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SecArray1_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SecArray1_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_SecArray1_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_SecArray1_IsAllocated(self)

    def Assign(self, theOther: "ChFiDS_SecArray1") -> "NCollection_Array1< ChFiDS_CircSection > &":
        return _ChFiDS.ChFiDS_SecArray1_Assign(self, theOther)

    def Move(self, theOther: "ChFiDS_SecArray1") -> "NCollection_Array1< ChFiDS_CircSection > &":
        return _ChFiDS.ChFiDS_SecArray1_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< ChFiDS_CircSection > &":
        return _ChFiDS.ChFiDS_SecArray1_Set(self, *args)

    def First(self) -> "ChFiDS_CircSection const &":
        return _ChFiDS.ChFiDS_SecArray1_First(self)

    def ChangeFirst(self) -> "ChFiDS_CircSection &":
        return _ChFiDS.ChFiDS_SecArray1_ChangeFirst(self)

    def Last(self) -> "ChFiDS_CircSection const &":
        return _ChFiDS.ChFiDS_SecArray1_Last(self)

    def ChangeLast(self) -> "ChFiDS_CircSection &":
        return _ChFiDS.ChFiDS_SecArray1_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "ChFiDS_CircSection const &":
        return _ChFiDS.ChFiDS_SecArray1_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "ChFiDS_CircSection &":
        return _ChFiDS.ChFiDS_SecArray1_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "ChFiDS_CircSection &":
        return _ChFiDS.ChFiDS_SecArray1___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "ChFiDS_CircSection") -> "void":
        return _ChFiDS.ChFiDS_SecArray1_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _ChFiDS.ChFiDS_SecArray1_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _ChFiDS.delete_ChFiDS_SecArray1

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register ChFiDS_SecArray1 in _ChFiDS:
_ChFiDS.ChFiDS_SecArray1_swigregister(ChFiDS_SecArray1)

class ChFiDS_SequenceOfSpine(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< ChFiDS_Spine > >::iterator":
        return _ChFiDS.ChFiDS_SequenceOfSpine_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< ChFiDS_Spine > >::iterator":
        return _ChFiDS.ChFiDS_SequenceOfSpine_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< ChFiDS_Spine > >::const_iterator":
        return _ChFiDS.ChFiDS_SequenceOfSpine_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< ChFiDS_Spine > >::const_iterator":
        return _ChFiDS.ChFiDS_SequenceOfSpine_cend(self)

    def __init__(self, *args):
        _ChFiDS.ChFiDS_SequenceOfSpine_swiginit(self, _ChFiDS.new_ChFiDS_SequenceOfSpine(*args))

    def Size(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Size(self)

    def Length(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_SequenceOfSpine_IsEmpty(self)

    def Reverse(self) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSpine_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Clear(self, theAllocator)

    def Assign(self, theOther: "ChFiDS_SequenceOfSpine") -> "NCollection_Sequence< opencascade::handle< ChFiDS_Spine > > &":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Assign(self, theOther)

    def Set(self, theOther: "ChFiDS_SequenceOfSpine") -> "NCollection_Sequence< opencascade::handle< ChFiDS_Spine > > &":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSpine_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSpine_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "ChFiDS_SequenceOfSpine") -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< ChFiDS_Spine > const &":
        return _ChFiDS.ChFiDS_SequenceOfSpine_First(self)

    def ChangeFirst(self) -> "opencascade::handle< ChFiDS_Spine > &":
        return _ChFiDS.ChFiDS_SequenceOfSpine_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< ChFiDS_Spine > const &":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Last(self)

    def ChangeLast(self) -> "opencascade::handle< ChFiDS_Spine > &":
        return _ChFiDS.ChFiDS_SequenceOfSpine_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< ChFiDS_Spine > const &":
        return _ChFiDS.ChFiDS_SequenceOfSpine_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< ChFiDS_Spine > &":
        return _ChFiDS.ChFiDS_SequenceOfSpine_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< ChFiDS_Spine > &":
        return _ChFiDS.ChFiDS_SequenceOfSpine___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< ChFiDS_Spine > const &") -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSpine_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _ChFiDS.delete_ChFiDS_SequenceOfSpine

    def __len__(self):
        return self.Size()


# Register ChFiDS_SequenceOfSpine in _ChFiDS:
_ChFiDS.ChFiDS_SequenceOfSpine_swigregister(ChFiDS_SequenceOfSpine)

def ChFiDS_SequenceOfSpine_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _ChFiDS.ChFiDS_SequenceOfSpine_delNode(theNode, theAl)

class ChFiDS_SequenceOfSurfData(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< ChFiDS_SurfData > >::iterator":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< ChFiDS_SurfData > >::iterator":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< ChFiDS_SurfData > >::const_iterator":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< ChFiDS_SurfData > >::const_iterator":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_cend(self)

    def __init__(self, *args):
        _ChFiDS.ChFiDS_SequenceOfSurfData_swiginit(self, _ChFiDS.new_ChFiDS_SequenceOfSurfData(*args))

    def Size(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Size(self)

    def Length(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_IsEmpty(self)

    def Reverse(self) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Clear(self, theAllocator)

    def Assign(self, theOther: "ChFiDS_SequenceOfSurfData") -> "NCollection_Sequence< opencascade::handle< ChFiDS_SurfData > > &":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Assign(self, theOther)

    def Set(self, theOther: "ChFiDS_SequenceOfSurfData") -> "NCollection_Sequence< opencascade::handle< ChFiDS_SurfData > > &":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "ChFiDS_SequenceOfSurfData") -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< ChFiDS_SurfData > const &":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_First(self)

    def ChangeFirst(self) -> "opencascade::handle< ChFiDS_SurfData > &":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< ChFiDS_SurfData > const &":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Last(self)

    def ChangeLast(self) -> "opencascade::handle< ChFiDS_SurfData > &":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< ChFiDS_SurfData > const &":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< ChFiDS_SurfData > &":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< ChFiDS_SurfData > &":
        return _ChFiDS.ChFiDS_SequenceOfSurfData___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< ChFiDS_SurfData > const &") -> "void":
        return _ChFiDS.ChFiDS_SequenceOfSurfData_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _ChFiDS.delete_ChFiDS_SequenceOfSurfData

    def __len__(self):
        return self.Size()


# Register ChFiDS_SequenceOfSurfData in _ChFiDS:
_ChFiDS.ChFiDS_SequenceOfSurfData_swigregister(ChFiDS_SequenceOfSurfData)

def ChFiDS_SequenceOfSurfData_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _ChFiDS.ChFiDS_SequenceOfSurfData_delNode(theNode, theAl)

class ChFiDS_StripeArray1(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< ChFiDS_Stripe > >::iterator":
        return _ChFiDS.ChFiDS_StripeArray1_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< ChFiDS_Stripe > >::iterator":
        return _ChFiDS.ChFiDS_StripeArray1_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< ChFiDS_Stripe > >::const_iterator":
        return _ChFiDS.ChFiDS_StripeArray1_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< ChFiDS_Stripe > >::const_iterator":
        return _ChFiDS.ChFiDS_StripeArray1_cend(self)

    def __init__(self, *args):
        _ChFiDS.ChFiDS_StripeArray1_swiginit(self, _ChFiDS.new_ChFiDS_StripeArray1(*args))

    def Init(self, theValue: "opencascade::handle< ChFiDS_Stripe > const &") -> "void":
        return _ChFiDS.ChFiDS_StripeArray1_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_StripeArray1_Size(self)

    def Length(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_StripeArray1_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_StripeArray1_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_StripeArray1_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _ChFiDS.ChFiDS_StripeArray1_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_StripeArray1_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _ChFiDS.ChFiDS_StripeArray1_IsAllocated(self)

    def Assign(self, theOther: "ChFiDS_StripeArray1") -> "NCollection_Array1< opencascade::handle< ChFiDS_Stripe > > &":
        return _ChFiDS.ChFiDS_StripeArray1_Assign(self, theOther)

    def Move(self, theOther: "ChFiDS_StripeArray1") -> "NCollection_Array1< opencascade::handle< ChFiDS_Stripe > > &":
        return _ChFiDS.ChFiDS_StripeArray1_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< ChFiDS_Stripe > > &":
        return _ChFiDS.ChFiDS_StripeArray1_Set(self, *args)

    def First(self) -> "opencascade::handle< ChFiDS_Stripe > const &":
        return _ChFiDS.ChFiDS_StripeArray1_First(self)

    def ChangeFirst(self) -> "opencascade::handle< ChFiDS_Stripe > &":
        return _ChFiDS.ChFiDS_StripeArray1_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< ChFiDS_Stripe > const &":
        return _ChFiDS.ChFiDS_StripeArray1_Last(self)

    def ChangeLast(self) -> "opencascade::handle< ChFiDS_Stripe > &":
        return _ChFiDS.ChFiDS_StripeArray1_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< ChFiDS_Stripe > const &":
        return _ChFiDS.ChFiDS_StripeArray1_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< ChFiDS_Stripe > &":
        return _ChFiDS.ChFiDS_StripeArray1_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< ChFiDS_Stripe > &":
        return _ChFiDS.ChFiDS_StripeArray1___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< ChFiDS_Stripe > const &") -> "void":
        return _ChFiDS.ChFiDS_StripeArray1_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _ChFiDS.ChFiDS_StripeArray1_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _ChFiDS.delete_ChFiDS_StripeArray1

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register ChFiDS_StripeArray1 in _ChFiDS:
_ChFiDS.ChFiDS_StripeArray1_swigregister(ChFiDS_StripeArray1)

class ChFiDS_CircSection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_CircSection_swiginit(self, _ChFiDS.new_ChFiDS_CircSection(*args))

    def Get(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        C: gp_Circ

        Returns
        -------
        F: float
        L: float
        No available documentation.

        Parameters
        ----------
        C: gp_Lin

        Returns
        -------
        F: float
        L: float

        """
        return _ChFiDS.ChFiDS_CircSection_Get(self, *args)

    def Set(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        C: gp_Circ
        F: float
        L: float

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Lin
        F: float
        L: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_CircSection_Set(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_CircSection

# Register ChFiDS_CircSection in _ChFiDS:
_ChFiDS.ChFiDS_CircSection_swigregister(ChFiDS_CircSection)

class ChFiDS_CommonPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_CommonPoint_swiginit(self, _ChFiDS.new_ChFiDS_CommonPoint(*args))

    def Arc(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the arc of restriction containing the vertex.

        Returns
        -------
        TopoDS_Edge

        """
        return _ChFiDS.ChFiDS_CommonPoint_Arc(self, *args)

    def HasVector(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the output vector is stored.

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_CommonPoint_HasVector(self, *args)

    def IsOnArc(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the point is a on an edge of the initial restriction facet of the surface.

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_CommonPoint_IsOnArc(self, *args)

    def IsVertex(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the point is a vertex on the initial restriction facet of the surface.

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_CommonPoint_IsVertex(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter the paramter on the spine.

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_CommonPoint_Parameter(self, *args)

    def ParameterOnArc(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter of the point on the arc returned by the method arc().

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_CommonPoint_ParameterOnArc(self, *args)

    def Point(self, *args) -> "gp_Pnt const":
        r"""
        Returns the 3d point.

        Returns
        -------
        gp_Pnt

        """
        return _ChFiDS.ChFiDS_CommonPoint_Point(self, *args)

    def Reset(self, *args) -> "void":
        r"""
        Default value for all fields.

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_CommonPoint_Reset(self, *args)

    def SetArc(self, *args) -> "void":
        r"""
        Sets the values of a point which is on the arc a, at parameter param.

        Parameters
        ----------
        Tol: float
        A: TopoDS_Edge
        Param: float
        TArc: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_CommonPoint_SetArc(self, *args)

    def SetParameter(self, *args) -> "void":
        r"""
        Sets the value of the parameter on the spine.

        Parameters
        ----------
        Param: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_CommonPoint_SetParameter(self, *args)

    def SetPoint(self, *args) -> "void":
        r"""
        Set the 3d point for a commonpoint that is not a vertex or on an arc.

        Parameters
        ----------
        thePoint: gp_Pnt

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_CommonPoint_SetPoint(self, *args)

    def SetTolerance(self, *args) -> "void":
        r"""
        This method set the fuzziness on the point.

        Parameters
        ----------
        Tol: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_CommonPoint_SetTolerance(self, *args)

    def SetVector(self, *args) -> "void":
        r"""
        Set the output 3d vector.

        Parameters
        ----------
        theVector: gp_Vec

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_CommonPoint_SetVector(self, *args)

    def SetVertex(self, *args) -> "void":
        r"""
        Sets the values of a point which is a vertex on the initial facet of restriction of one of the surface.

        Parameters
        ----------
        theVertex: TopoDS_Vertex

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_CommonPoint_SetVertex(self, *args)

    def Tolerance(self, *args) -> "Standard_Real":
        r"""
        This method returns the fuzziness on the point.

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_CommonPoint_Tolerance(self, *args)

    def TransitionOnArc(self, *args) -> "TopAbs_Orientation":
        r"""
        Returns the transition of the point on the arc returned by arc().

        Returns
        -------
        TopAbs_Orientation

        """
        return _ChFiDS.ChFiDS_CommonPoint_TransitionOnArc(self, *args)

    def Vector(self, *args) -> "gp_Vec const":
        r"""
        Returns the output 3d vector.

        Returns
        -------
        gp_Vec

        """
        return _ChFiDS.ChFiDS_CommonPoint_Vector(self, *args)

    def Vertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        Returns the information about the point when it is on the domain of the first patch, i-e when the function isvertex returns true. otherwise, an exception is raised.

        Returns
        -------
        TopoDS_Vertex

        """
        return _ChFiDS.ChFiDS_CommonPoint_Vertex(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_CommonPoint

# Register ChFiDS_CommonPoint in _ChFiDS:
_ChFiDS.ChFiDS_CommonPoint_swigregister(ChFiDS_CommonPoint)

class ChFiDS_ElSpine(OCC.Core.Adaptor3d.Adaptor3d_Curve):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_ElSpine_swiginit(self, _ChFiDS.new_ChFiDS_ElSpine(*args))

    def AddVertexWithTangent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anAx1: gp_Ax1

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_AddVertexWithTangent(self, *args)

    def ChangeNext(self, *args) -> "opencascade::handle< ChFiDS_SurfData > &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<ChFiDS_SurfData>

        """
        return _ChFiDS.ChFiDS_ElSpine_ChangeNext(self, *args)

    def ChangePrevious(self, *args) -> "opencascade::handle< ChFiDS_SurfData > &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<ChFiDS_SurfData>

        """
        return _ChFiDS.ChFiDS_ElSpine_ChangePrevious(self, *args)

    def FirstParameter(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        P: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_FirstParameter(self, *args)

    def FirstPointAndTgt(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt
        T: gp_Vec

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_FirstPointAndTgt(self, *args)

    def GetSavedFirstParameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_ElSpine_GetSavedFirstParameter(self, *args)

    def GetSavedLastParameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_ElSpine_GetSavedLastParameter(self, *args)

    def LastParameter(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        P: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_LastParameter(self, *args)

    def LastPointAndTgt(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt
        T: gp_Vec

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_LastPointAndTgt(self, *args)

    def NbVertices(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_ElSpine_NbVertices(self, *args)

    def Next(self, *args) -> "opencascade::handle< ChFiDS_SurfData > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<ChFiDS_SurfData>

        """
        return _ChFiDS.ChFiDS_ElSpine_Next(self, *args)

    def Previous(self, *args) -> "opencascade::handle< ChFiDS_SurfData > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<ChFiDS_SurfData>

        """
        return _ChFiDS.ChFiDS_ElSpine_Previous(self, *args)

    def SaveFirstParameter(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_SaveFirstParameter(self, *args)

    def SaveLastParameter(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_SaveLastParameter(self, *args)

    def SetCurve(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom_Curve

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_SetCurve(self, *args)

    def SetFirstPointAndTgt(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt
        T: gp_Vec

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_SetFirstPointAndTgt(self, *args)

    def SetLastPointAndTgt(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt
        T: gp_Vec

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_SetLastPointAndTgt(self, *args)

    def SetOrigin(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        O: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_SetOrigin(self, *args)

    def SetPeriodic(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        I: bool

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ElSpine_SetPeriodic(self, *args)

    def VertexWithTangent(self, *args) -> "gp_Ax1 const":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Ax1

        """
        return _ChFiDS.ChFiDS_ElSpine_VertexWithTangent(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_ElSpine

# Register ChFiDS_ElSpine in _ChFiDS:
_ChFiDS.ChFiDS_ElSpine_swigregister(ChFiDS_ElSpine)

class ChFiDS_FaceInterference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_FaceInterference_swiginit(self, _ChFiDS.new_ChFiDS_FaceInterference(*args))

    def ChangePCurveOnFace(self, *args) -> "opencascade::handle< Geom2d_Curve > &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _ChFiDS.ChFiDS_FaceInterference_ChangePCurveOnFace(self, *args)

    def ChangePCurveOnSurf(self, *args) -> "opencascade::handle< Geom2d_Curve > &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _ChFiDS.ChFiDS_FaceInterference_ChangePCurveOnSurf(self, *args)

    def FirstParameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_FaceInterference_FirstParameter(self, *args)

    def LastParameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_FaceInterference_LastParameter(self, *args)

    def LineIndex(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_FaceInterference_LineIndex(self, *args)

    def PCurveOnFace(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _ChFiDS.ChFiDS_FaceInterference_PCurveOnFace(self, *args)

    def PCurveOnSurf(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _ChFiDS.ChFiDS_FaceInterference_PCurveOnSurf(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        IsFirst: bool

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_FaceInterference_Parameter(self, *args)

    def SetFirstParameter(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U1: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_FaceInterference_SetFirstParameter(self, *args)

    def SetInterference(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LineIndex: int
        Trans: TopAbs_Orientation
        PCurv1: Geom2d_Curve
        PCurv2: Geom2d_Curve

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_FaceInterference_SetInterference(self, *args)

    def SetLastParameter(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U1: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_FaceInterference_SetLastParameter(self, *args)

    def SetLineIndex(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_FaceInterference_SetLineIndex(self, *args)

    def SetParameter(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U1: float
        IsFirst: bool

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_FaceInterference_SetParameter(self, *args)

    def SetTransition(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Trans: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_FaceInterference_SetTransition(self, *args)

    def Transition(self, *args) -> "TopAbs_Orientation":
        r"""
        No available documentation.

        Returns
        -------
        TopAbs_Orientation

        """
        return _ChFiDS.ChFiDS_FaceInterference_Transition(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_FaceInterference

# Register ChFiDS_FaceInterference in _ChFiDS:
_ChFiDS.ChFiDS_FaceInterference_swigregister(ChFiDS_FaceInterference)

class ChFiDS_HElSpine(OCC.Core.Adaptor3d.Adaptor3d_HCurve):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an empty genhcurve.

        Returns
        -------
        None
        Creates a genhcurve from a curve.

        Parameters
        ----------
        C: ChFiDS_ElSpine

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_HElSpine_swiginit(self, _ChFiDS.new_ChFiDS_HElSpine(*args))

    def ChangeCurve(self, *args) -> "ChFiDS_ElSpine &":
        r"""
        Returns the curve used to create the genhcurve.

        Returns
        -------
        ChFiDS_ElSpine

        """
        return _ChFiDS.ChFiDS_HElSpine_ChangeCurve(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Sets the field of the genhcurve.

        Parameters
        ----------
        C: ChFiDS_ElSpine

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_HElSpine_Set(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ChFiDS_HElSpine_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_HElSpine

# Register ChFiDS_HElSpine in _ChFiDS:
_ChFiDS.ChFiDS_HElSpine_swigregister(ChFiDS_HElSpine)

class ChFiDS_Map(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create an empty map.

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_Map_swiginit(self, _ChFiDS.new_ChFiDS_Map(*args))

    def Contains(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_Map_Contains(self, *args)

    def Fill(self, *args) -> "void":
        r"""
        Fills the map with the subshapes of type t1 as keys and the list of ancestors of type t2 as items.

        Parameters
        ----------
        S: TopoDS_Shape
        T1: TopAbs_ShapeEnum
        T2: TopAbs_ShapeEnum

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Map_Fill(self, *args)

    def FindFromIndex(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopTools_ListOfShape

        """
        return _ChFiDS.ChFiDS_Map_FindFromIndex(self, *args)

    def FindFromKey(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        TopTools_ListOfShape

        """
        return _ChFiDS.ChFiDS_Map_FindFromKey(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_Map

# Register ChFiDS_Map in _ChFiDS:
_ChFiDS.ChFiDS_Map_swigregister(ChFiDS_Map)

class ChFiDS_Regul(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_Regul_swiginit(self, _ChFiDS.new_ChFiDS_Regul(*args))

    def Curve(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Regul_Curve(self, *args)

    def IsSurface1(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_Regul_IsSurface1(self, *args)

    def IsSurface2(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_Regul_IsSurface2(self, *args)

    def S1(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Regul_S1(self, *args)

    def S2(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Regul_S2(self, *args)

    def SetCurve(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Regul_SetCurve(self, *args)

    def SetS1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IS1: int
        IsFace: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Regul_SetS1(self, *args)

    def SetS2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IS2: int
        IsFace: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Regul_SetS2(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_Regul

# Register ChFiDS_Regul in _ChFiDS:
_ChFiDS.ChFiDS_Regul_swigregister(ChFiDS_Regul)

class ChFiDS_Spine(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Tol: float

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_Spine_swiginit(self, _ChFiDS.new_ChFiDS_Spine(*args))

    def Absc(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        U: float
        I: int

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        V: TopoDS_Vertex

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_Spine_Absc(self, *args)

    def AppendElSpine(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Els: ChFiDS_HElSpine

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_AppendElSpine(self, *args)

    def AppendOffsetElSpine(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Els: ChFiDS_HElSpine

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_AppendOffsetElSpine(self, *args)

    def ChangeElSpines(self, *args) -> "ChFiDS_ListOfHElSpine &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_ListOfHElSpine

        """
        return _ChFiDS.ChFiDS_Spine_ChangeElSpines(self, *args)

    def ChangeOffsetElSpines(self, *args) -> "ChFiDS_ListOfHElSpine &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_ListOfHElSpine

        """
        return _ChFiDS.ChFiDS_Spine_ChangeOffsetElSpines(self, *args)

    def Circle(self, *args) -> "gp_Circ":
        r"""
        No available documentation.

        Returns
        -------
        gp_Circ

        """
        return _ChFiDS.ChFiDS_Spine_Circle(self, *args)

    def CurrentElementarySpine(self, *args) -> "BRepAdaptor_Curve const &":
        r"""
        Sets the current curve and returns it.

        Parameters
        ----------
        Index: int

        Returns
        -------
        BRepAdaptor_Curve

        """
        return _ChFiDS.ChFiDS_Spine_CurrentElementarySpine(self, *args)

    def CurrentIndexOfElementarySpine(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Spine_CurrentIndexOfElementarySpine(self, *args)

    def D0(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        AbsC: float
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_D0(self, *args)

    def D1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        AbsC: float
        P: gp_Pnt
        V1: gp_Vec

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_D1(self, *args)

    def D2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        AbsC: float
        P: gp_Pnt
        V1: gp_Vec
        V2: gp_Vec

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_D2(self, *args)

    def Edges(self, *args) -> "TopoDS_Edge const":
        r"""
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopoDS_Edge

        """
        return _ChFiDS.ChFiDS_Spine_Edges(self, *args)

    def ElSpine(self, *args) -> "opencascade::handle< ChFiDS_HElSpine >":
        r"""
        No available documentation.

        Parameters
        ----------
        IE: int

        Returns
        -------
        opencascade::handle<ChFiDS_HElSpine>
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        opencascade::handle<ChFiDS_HElSpine>
        No available documentation.

        Parameters
        ----------
        W: float

        Returns
        -------
        opencascade::handle<ChFiDS_HElSpine>

        """
        return _ChFiDS.ChFiDS_Spine_ElSpine(self, *args)

    def ErrorStatus(self, *args) -> "ChFiDS_ErrorStatus":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_ErrorStatus

        """
        return _ChFiDS.ChFiDS_Spine_ErrorStatus(self, *args)

    def FirstParameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float
        Gives the total length of all arcs before the number indexsp.

        Parameters
        ----------
        IndexSpine: int

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_Spine_FirstParameter(self, *args)

    def FirstStatus(self, *args) -> "ChFiDS_State":
        r"""
        Returns if the set of edges starts on a free boundary or if the first vertex is a breakpoint or if the set is closed.

        Returns
        -------
        ChFiDS_State

        """
        return _ChFiDS.ChFiDS_Spine_FirstStatus(self, *args)

    def FirstVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Vertex

        """
        return _ChFiDS.ChFiDS_Spine_FirstVertex(self, *args)

    def GetType(self, *args) -> "GeomAbs_CurveType":
        r"""
        No available documentation.

        Returns
        -------
        GeomAbs_CurveType

        """
        return _ChFiDS.ChFiDS_Spine_GetType(self, *args)

    def GetTypeOfConcavity(self, *args) -> "ChFiDS_TypeOfConcavity":
        r"""
        Returns the type of concavity in the connection.

        Returns
        -------
        ChFiDS_TypeOfConcavity

        """
        return _ChFiDS.ChFiDS_Spine_GetTypeOfConcavity(self, *args)

    def HasFirstTgt(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_Spine_HasFirstTgt(self, *args)

    def HasLastTgt(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_Spine_HasLastTgt(self, *args)

    def Index(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        W: float
        Forward: bool,optional
        	default value is Standard_True

        Returns
        -------
        int
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Spine_Index(self, *args)

    def IsClosed(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_Spine_IsClosed(self, *args)

    def IsPeriodic(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_Spine_IsPeriodic(self, *args)

    def IsTangencyExtremity(self, *args) -> "Standard_Boolean":
        r"""
        Returns if the set of edges starts (or end) on tangency point.

        Parameters
        ----------
        IsFirst: bool

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_Spine_IsTangencyExtremity(self, *args)

    def LastParameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float
        Gives the total length till the ark with number indexspine (inclus).

        Parameters
        ----------
        IndexSpine: int

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_Spine_LastParameter(self, *args)

    def LastStatus(self, *args) -> "ChFiDS_State":
        r"""
        Returns the state at the end of the set.

        Returns
        -------
        ChFiDS_State

        """
        return _ChFiDS.ChFiDS_Spine_LastStatus(self, *args)

    def LastVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Vertex

        """
        return _ChFiDS.ChFiDS_Spine_LastVertex(self, *args)

    def Length(self, *args) -> "Standard_Real":
        r"""
        Gives the length of ark with number indexsp.

        Parameters
        ----------
        IndexSpine: int

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_Spine_Length(self, *args)

    def Line(self, *args) -> "gp_Lin":
        r"""
        No available documentation.

        Returns
        -------
        gp_Lin

        """
        return _ChFiDS.ChFiDS_Spine_Line(self, *args)

    def Load(self, *args) -> "void":
        r"""
        Prepare the guideline depending on the edges that are elementary arks (take parameters from a single curvilinear abscissa); to be able to call methods on the geometry (first,last,value,d1,d2) it is necessary to start with preparation otherwise an exception will be raised.

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_Load(self, *args)

    def Mode(self, *args) -> "ChFiDS_ChamfMode":
        r"""
        Return the mode of chamfers used.

        Returns
        -------
        ChFiDS_ChamfMode

        """
        return _ChFiDS.ChFiDS_Spine_Mode(self, *args)

    def NbEdges(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Spine_NbEdges(self, *args)

    def OffsetEdges(self, *args) -> "TopoDS_Edge const":
        r"""
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopoDS_Edge

        """
        return _ChFiDS.ChFiDS_Spine_OffsetEdges(self, *args)

    def Parameter(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        AbsC: float
        Oriented: bool,optional
        	default value is Standard_True

        Returns
        -------
        U: float
        No available documentation.

        Parameters
        ----------
        Index: int
        AbsC: float
        Oriented: bool,optional
        	default value is Standard_True

        Returns
        -------
        U: float

        """
        return _ChFiDS.ChFiDS_Spine_Parameter(self, *args)

    def Period(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_Spine_Period(self, *args)

    def PutInFirst(self, *args) -> "void":
        r"""
        Store the edge at the first position before all others.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_PutInFirst(self, *args)

    def PutInFirstOffset(self, *args) -> "void":
        r"""
        Store the offset edge at the first position before all others.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_PutInFirstOffset(self, *args)

    def Reset(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        AllData: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_Reset(self, *args)

    def Resolution(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        R3d: float

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_Spine_Resolution(self, *args)

    def SetCurrent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetCurrent(self, *args)

    def SetEdges(self, *args) -> "void":
        r"""
        Store edges composing the guideline.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetEdges(self, *args)

    def SetErrorStatus(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        state: ChFiDS_ErrorStatus

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetErrorStatus(self, *args)

    def SetFirstParameter(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Par: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetFirstParameter(self, *args)

    def SetFirstStatus(self, *args) -> "void":
        r"""
        Stores if the start of a set of edges starts on a section of free border or forms a closed contour.

        Parameters
        ----------
        S: ChFiDS_State

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetFirstStatus(self, *args)

    def SetFirstTgt(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        W: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetFirstTgt(self, *args)

    def SetLastParameter(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Par: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetLastParameter(self, *args)

    def SetLastStatus(self, *args) -> "void":
        r"""
        Stores if the end of a set of edges starts on a section of free border or forms a closed contour.

        Parameters
        ----------
        S: ChFiDS_State

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetLastStatus(self, *args)

    def SetLastTgt(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        W: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetLastTgt(self, *args)

    def SetOffsetEdges(self, *args) -> "void":
        r"""
        Store offset edges composing the offset guideline.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetOffsetEdges(self, *args)

    def SetReference(self, *args) -> "void":
        r"""
        Set a parameter reference for the approx.

        Parameters
        ----------
        W: float

        Returns
        -------
        None
        Set a parameter reference for the approx, at the middle of edge i.

        Parameters
        ----------
        I: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetReference(self, *args)

    def SetStatus(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: ChFiDS_State
        IsFirst: bool

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetStatus(self, *args)

    def SetTangencyExtremity(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IsTangency: bool
        IsFirst: bool

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetTangencyExtremity(self, *args)

    def SetTypeOfConcavity(self, *args) -> "void":
        r"""
        Sets the type of concavity in the connection.

        Parameters
        ----------
        theType: ChFiDS_TypeOfConcavity

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SetTypeOfConcavity(self, *args)

    def SplitDone(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        B: bool

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_SplitDone(self, *args)

    def Status(self, *args) -> "ChFiDS_State":
        r"""
        No available documentation.

        Parameters
        ----------
        IsFirst: bool

        Returns
        -------
        ChFiDS_State

        """
        return _ChFiDS.ChFiDS_Spine_Status(self, *args)

    def UnsetReference(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Spine_UnsetReference(self, *args)

    def Value(self, *args) -> "gp_Pnt":
        r"""
        No available documentation.

        Parameters
        ----------
        AbsC: float

        Returns
        -------
        gp_Pnt

        """
        return _ChFiDS.ChFiDS_Spine_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ChFiDS_Spine_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_Spine

# Register ChFiDS_Spine in _ChFiDS:
_ChFiDS.ChFiDS_Spine_swigregister(ChFiDS_Spine)

class ChFiDS_Stripe(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_Stripe_swiginit(self, _ChFiDS.new_ChFiDS_Stripe(*args))

    def ChangeFirstCurve(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeFirstCurve(self, *args)

    def ChangeFirstPCurve(self, *args) -> "opencascade::handle< Geom2d_Curve > &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeFirstPCurve(self, *args)

    def ChangeFirstParameters(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Pdeb: float
        Pfin: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeFirstParameters(self, *args)

    def ChangeIndexFirstPointOnS1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeIndexFirstPointOnS1(self, *args)

    def ChangeIndexFirstPointOnS2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeIndexFirstPointOnS2(self, *args)

    def ChangeIndexLastPointOnS1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeIndexLastPointOnS1(self, *args)

    def ChangeIndexLastPointOnS2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeIndexLastPointOnS2(self, *args)

    def ChangeLastCurve(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeLastCurve(self, *args)

    def ChangeLastPCurve(self, *args) -> "opencascade::handle< Geom2d_Curve > &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeLastPCurve(self, *args)

    def ChangeLastParameters(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Pdeb: float
        Pfin: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeLastParameters(self, *args)

    def ChangePCurve(self, *args) -> "opencascade::handle< Geom2d_Curve > &":
        r"""
        No available documentation.

        Parameters
        ----------
        First: bool

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _ChFiDS.ChFiDS_Stripe_ChangePCurve(self, *args)

    def ChangeSetOfSurfData(self, *args) -> "opencascade::handle< ChFiDS_HData > &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<ChFiDS_HData>

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeSetOfSurfData(self, *args)

    def ChangeSpine(self, *args) -> "opencascade::handle< ChFiDS_Spine > &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<ChFiDS_Spine>

        """
        return _ChFiDS.ChFiDS_Stripe_ChangeSpine(self, *args)

    def Choix(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        int
        No available documentation.

        Parameters
        ----------
        C: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_Choix(self, *args)

    def Curve(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        First: bool

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Stripe_Curve(self, *args)

    def FirstCurve(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Stripe_FirstCurve(self, *args)

    def FirstPCurve(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _ChFiDS.ChFiDS_Stripe_FirstPCurve(self, *args)

    def FirstPCurveOrientation(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        TopAbs_Orientation
        No available documentation.

        Parameters
        ----------
        O: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_FirstPCurveOrientation(self, *args)

    def FirstParameters(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        Pdeb: float
        Pfin: float

        """
        return _ChFiDS.ChFiDS_Stripe_FirstParameters(self, *args)

    def InDS(self, *args) -> "void":
        r"""
        Set nb of surfdata's at end put in ds.

        Parameters
        ----------
        First: bool
        Nb: int,optional
        	default value is 1

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_InDS(self, *args)

    def IndexFirstPointOnS1(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Stripe_IndexFirstPointOnS1(self, *args)

    def IndexFirstPointOnS2(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Stripe_IndexFirstPointOnS2(self, *args)

    def IndexLastPointOnS1(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Stripe_IndexLastPointOnS1(self, *args)

    def IndexLastPointOnS2(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Stripe_IndexLastPointOnS2(self, *args)

    def IndexPoint(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        First: bool
        OnS: int

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Stripe_IndexPoint(self, *args)

    def IsInDS(self, *args) -> "Standard_Integer":
        r"""
        Returns nb of surfdata's at end being in ds.

        Parameters
        ----------
        First: bool

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Stripe_IsInDS(self, *args)

    def LastCurve(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Stripe_LastCurve(self, *args)

    def LastPCurve(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _ChFiDS.ChFiDS_Stripe_LastPCurve(self, *args)

    def LastPCurveOrientation(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        TopAbs_Orientation
        No available documentation.

        Parameters
        ----------
        O: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_LastPCurveOrientation(self, *args)

    def LastParameters(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        Pdeb: float
        Pfin: float

        """
        return _ChFiDS.ChFiDS_Stripe_LastParameters(self, *args)

    def Orientation(self, *args) -> "TopAbs_Orientation":
        r"""
        No available documentation.

        Parameters
        ----------
        OnS: int

        Returns
        -------
        TopAbs_Orientation
        No available documentation.

        Parameters
        ----------
        First: bool

        Returns
        -------
        TopAbs_Orientation

        """
        return _ChFiDS.ChFiDS_Stripe_Orientation(self, *args)

    def OrientationOnFace1(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        TopAbs_Orientation
        No available documentation.

        Parameters
        ----------
        Or1: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_OrientationOnFace1(self, *args)

    def OrientationOnFace2(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        TopAbs_Orientation
        No available documentation.

        Parameters
        ----------
        Or2: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_OrientationOnFace2(self, *args)

    def PCurve(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        No available documentation.

        Parameters
        ----------
        First: bool

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _ChFiDS.ChFiDS_Stripe_PCurve(self, *args)

    def Parameters(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        First: bool

        Returns
        -------
        Pdeb: float
        Pfin: float

        """
        return _ChFiDS.ChFiDS_Stripe_Parameters(self, *args)

    def Reset(self, *args) -> "void":
        r"""
        Reset everything except spine.

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_Reset(self, *args)

    def SetCurve(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int
        First: bool

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_SetCurve(self, *args)

    def SetIndexPoint(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int
        First: bool
        OnS: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_SetIndexPoint(self, *args)

    def SetOfSurfData(self, *args) -> "opencascade::handle< ChFiDS_HData > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<ChFiDS_HData>

        """
        return _ChFiDS.ChFiDS_Stripe_SetOfSurfData(self, *args)

    def SetOrientation(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Or: TopAbs_Orientation
        OnS: int

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Or: TopAbs_Orientation
        First: bool

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_SetOrientation(self, *args)

    def SetParameters(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        First: bool
        Pdeb: float
        Pfin: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_SetParameters(self, *args)

    def SetSolidIndex(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_Stripe_SetSolidIndex(self, *args)

    def SolidIndex(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_Stripe_SolidIndex(self, *args)

    def Spine(self, *args) -> "opencascade::handle< ChFiDS_Spine > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<ChFiDS_Spine>

        """
        return _ChFiDS.ChFiDS_Stripe_Spine(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ChFiDS_Stripe_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_Stripe

# Register ChFiDS_Stripe in _ChFiDS:
_ChFiDS.ChFiDS_Stripe_swigregister(ChFiDS_Stripe)

class ChFiDS_StripeMap(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_StripeMap_swiginit(self, _ChFiDS.new_ChFiDS_StripeMap(*args))

    def Add(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        V: TopoDS_Vertex
        F: ChFiDS_Stripe

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_StripeMap_Add(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_StripeMap_Clear(self, *args)

    def Extent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_StripeMap_Extent(self, *args)

    def FindFromIndex(self, *args) -> "ChFiDS_ListOfStripe const &":
        r"""
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        ChFiDS_ListOfStripe

        """
        return _ChFiDS.ChFiDS_StripeMap_FindFromIndex(self, *args)

    def FindFromKey(self, *args) -> "ChFiDS_ListOfStripe const &":
        r"""
        No available documentation.

        Parameters
        ----------
        V: TopoDS_Vertex

        Returns
        -------
        ChFiDS_ListOfStripe

        """
        return _ChFiDS.ChFiDS_StripeMap_FindFromKey(self, *args)

    def FindKey(self, *args) -> "TopoDS_Vertex const":
        r"""
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopoDS_Vertex

        """
        return _ChFiDS.ChFiDS_StripeMap_FindKey(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_StripeMap

# Register ChFiDS_StripeMap in _ChFiDS:
_ChFiDS.ChFiDS_StripeMap_swigregister(ChFiDS_StripeMap)

class ChFiDS_SurfData(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_SurfData_swiginit(self, _ChFiDS.new_ChFiDS_SurfData(*args))

    def ChangeIndexOfS1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeIndexOfS1(self, *args)

    def ChangeIndexOfS2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeIndexOfS2(self, *args)

    def ChangeInterference(self, *args) -> "ChFiDS_FaceInterference &":
        r"""
        No available documentation.

        Parameters
        ----------
        OnS: int

        Returns
        -------
        ChFiDS_FaceInterference

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeInterference(self, *args)

    def ChangeInterferenceOnS1(self, *args) -> "ChFiDS_FaceInterference &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_FaceInterference

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeInterferenceOnS1(self, *args)

    def ChangeInterferenceOnS2(self, *args) -> "ChFiDS_FaceInterference &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_FaceInterference

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeInterferenceOnS2(self, *args)

    def ChangeOrientation(self, *args) -> "TopAbs_Orientation &":
        r"""
        No available documentation.

        Returns
        -------
        TopAbs_Orientation

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeOrientation(self, *args)

    def ChangeSurf(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeSurf(self, *args)

    def ChangeVertex(self, *args) -> "ChFiDS_CommonPoint &":
        r"""
        Returns one of the four vertices wether first is true or wrong and ons equals 1 or 2.

        Parameters
        ----------
        First: bool
        OnS: int

        Returns
        -------
        ChFiDS_CommonPoint

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeVertex(self, *args)

    def ChangeVertexFirstOnS1(self, *args) -> "ChFiDS_CommonPoint &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_CommonPoint

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeVertexFirstOnS1(self, *args)

    def ChangeVertexFirstOnS2(self, *args) -> "ChFiDS_CommonPoint &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_CommonPoint

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeVertexFirstOnS2(self, *args)

    def ChangeVertexLastOnS1(self, *args) -> "ChFiDS_CommonPoint &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_CommonPoint

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeVertexLastOnS1(self, *args)

    def ChangeVertexLastOnS2(self, *args) -> "ChFiDS_CommonPoint &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_CommonPoint

        """
        return _ChFiDS.ChFiDS_SurfData_ChangeVertexLastOnS2(self, *args)

    def Copy(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Other: ChFiDS_SurfData

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_Copy(self, *args)

    def FirstExtensionValue(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        Extend: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_FirstExtensionValue(self, *args)

    def FirstSpineParam(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        Par: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_FirstSpineParam(self, *args)

    def Get2dPoints(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        First: bool
        OnS: int

        Returns
        -------
        gp_Pnt2d
        No available documentation.

        Parameters
        ----------
        P2df1: gp_Pnt2d
        P2dl1: gp_Pnt2d
        P2df2: gp_Pnt2d
        P2dl2: gp_Pnt2d

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_Get2dPoints(self, *args)

    def Index(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        OfS: int

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_SurfData_Index(self, *args)

    def IndexOfC(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        OnS: int

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_SurfData_IndexOfC(self, *args)

    def IndexOfC1(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_SurfData_IndexOfC1(self, *args)

    def IndexOfC2(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_SurfData_IndexOfC2(self, *args)

    def IndexOfS1(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_SurfData_IndexOfS1(self, *args)

    def IndexOfS2(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_SurfData_IndexOfS2(self, *args)

    def Interference(self, *args) -> "ChFiDS_FaceInterference const &":
        r"""
        No available documentation.

        Parameters
        ----------
        OnS: int

        Returns
        -------
        ChFiDS_FaceInterference

        """
        return _ChFiDS.ChFiDS_SurfData_Interference(self, *args)

    def InterferenceOnS1(self, *args) -> "ChFiDS_FaceInterference const &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_FaceInterference

        """
        return _ChFiDS.ChFiDS_SurfData_InterferenceOnS1(self, *args)

    def InterferenceOnS2(self, *args) -> "ChFiDS_FaceInterference const &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_FaceInterference

        """
        return _ChFiDS.ChFiDS_SurfData_InterferenceOnS2(self, *args)

    def IsOnCurve(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        OnS: int

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_SurfData_IsOnCurve(self, *args)

    def IsOnCurve1(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_SurfData_IsOnCurve1(self, *args)

    def IsOnCurve2(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_SurfData_IsOnCurve2(self, *args)

    def LastExtensionValue(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        Extend: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_LastExtensionValue(self, *args)

    def LastSpineParam(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        Par: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_LastSpineParam(self, *args)

    def Orientation(self, *args) -> "TopAbs_Orientation":
        r"""
        No available documentation.

        Returns
        -------
        TopAbs_Orientation

        """
        return _ChFiDS.ChFiDS_SurfData_Orientation(self, *args)

    def ResetSimul(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_ResetSimul(self, *args)

    def Set2dPoints(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        P2df1: gp_Pnt2d
        P2dl1: gp_Pnt2d
        P2df2: gp_Pnt2d
        P2dl2: gp_Pnt2d

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_Set2dPoints(self, *args)

    def SetIndexOfC1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_SetIndexOfC1(self, *args)

    def SetIndexOfC2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_SetIndexOfC2(self, *args)

    def SetSimul(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: Standard_Transient

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_SetSimul(self, *args)

    def Simul(self, *args) -> "opencascade::handle< Standard_Transient >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _ChFiDS.ChFiDS_SurfData_Simul(self, *args)

    def Surf(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ChFiDS.ChFiDS_SurfData_Surf(self, *args)

    def TwistOnS1(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        T: bool

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_TwistOnS1(self, *args)

    def TwistOnS2(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        T: bool

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_SurfData_TwistOnS2(self, *args)

    def Vertex(self, *args) -> "ChFiDS_CommonPoint const &":
        r"""
        Returns one of the four vertices wether first is true or wrong and ons equals 1 or 2.

        Parameters
        ----------
        First: bool
        OnS: int

        Returns
        -------
        ChFiDS_CommonPoint

        """
        return _ChFiDS.ChFiDS_SurfData_Vertex(self, *args)

    def VertexFirstOnS1(self, *args) -> "ChFiDS_CommonPoint const &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_CommonPoint

        """
        return _ChFiDS.ChFiDS_SurfData_VertexFirstOnS1(self, *args)

    def VertexFirstOnS2(self, *args) -> "ChFiDS_CommonPoint const &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_CommonPoint

        """
        return _ChFiDS.ChFiDS_SurfData_VertexFirstOnS2(self, *args)

    def VertexLastOnS1(self, *args) -> "ChFiDS_CommonPoint const &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_CommonPoint

        """
        return _ChFiDS.ChFiDS_SurfData_VertexLastOnS1(self, *args)

    def VertexLastOnS2(self, *args) -> "ChFiDS_CommonPoint const &":
        r"""
        No available documentation.

        Returns
        -------
        ChFiDS_CommonPoint

        """
        return _ChFiDS.ChFiDS_SurfData_VertexLastOnS2(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ChFiDS_SurfData_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_SurfData

# Register ChFiDS_SurfData in _ChFiDS:
_ChFiDS.ChFiDS_SurfData_swigregister(ChFiDS_SurfData)

class ChFiDS_ChamfSpine(ChFiDS_Spine):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Tol: float

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_ChamfSpine_swiginit(self, _ChFiDS.new_ChFiDS_ChamfSpine(*args))

    def Dists(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        Dis1: float
        Dis2: float

        """
        return _ChFiDS.ChFiDS_ChamfSpine_Dists(self, *args)

    def GetDist(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        Dis: float

        """
        return _ChFiDS.ChFiDS_ChamfSpine_GetDist(self, *args)

    def GetDistAngle(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        Dis: float
        Angle: float

        """
        return _ChFiDS.ChFiDS_ChamfSpine_GetDistAngle(self, *args)

    def IsChamfer(self, *args) -> "ChFiDS_ChamfMethod":
        r"""
        Return the method of chamfers used.

        Returns
        -------
        ChFiDS_ChamfMethod

        """
        return _ChFiDS.ChFiDS_ChamfSpine_IsChamfer(self, *args)

    def SetDist(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Dis: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ChamfSpine_SetDist(self, *args)

    def SetDistAngle(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Dis: float
        Angle: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ChamfSpine_SetDistAngle(self, *args)

    def SetDists(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Dis1: float
        Dis2: float

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ChamfSpine_SetDists(self, *args)

    def SetMode(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theMode: ChFiDS_ChamfMode

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_ChamfSpine_SetMode(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ChFiDS_ChamfSpine_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_ChamfSpine

# Register ChFiDS_ChamfSpine in _ChFiDS:
_ChFiDS.ChFiDS_ChamfSpine_swigregister(ChFiDS_ChamfSpine)

class ChFiDS_FilSpine(ChFiDS_Spine):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Tol: float

        Returns
        -------
        None

        """
        _ChFiDS.ChFiDS_FilSpine_swiginit(self, _ChFiDS.new_ChFiDS_FilSpine(*args))

    def ChangeLaw(self, *args) -> "opencascade::handle< Law_Function > &":
        r"""
        Returns the elementary law.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        opencascade::handle<Law_Function>

        """
        return _ChFiDS.ChFiDS_FilSpine_ChangeLaw(self, *args)

    def IsConstant(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the radius is constant all along the spine.

        Returns
        -------
        bool
        Returns true if the radius is constant all along the edge e.

        Parameters
        ----------
        IE: int

        Returns
        -------
        bool

        """
        return _ChFiDS.ChFiDS_FilSpine_IsConstant(self, *args)

    def law(self, *args) -> "opencascade::handle< Law_Composite >":
        r"""
        No available documentation.

        Parameters
        ----------
        Els: ChFiDS_HElSpine

        Returns
        -------
        opencascade::handle<Law_Composite>

        """
        return _ChFiDS.ChFiDS_FilSpine_law(self, *args)

    def MaxRadFromSeqAndLaws(self, *args) -> "Standard_Real":
        r"""
        Returns the maximum radius if the fillet is non-constant.

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_FilSpine_MaxRadFromSeqAndLaws(self, *args)

    def Radius(self, *args) -> "Standard_Real":
        r"""
        Returns the radius if the fillet is constant all along the spine.

        Returns
        -------
        float
        Returns the radius if the fillet is constant all along the edge e.

        Parameters
        ----------
        IE: int

        Returns
        -------
        float
        Returns the radius if the fillet is constant all along the edge e.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        float

        """
        return _ChFiDS.ChFiDS_FilSpine_Radius(self, *args)

    def SetRadius(self, *args) -> "void":
        r"""
        Initializes the constant vector on edge e.

        Parameters
        ----------
        Radius: float
        E: TopoDS_Edge

        Returns
        -------
        None
        Initializes the vector on vertex v.

        Parameters
        ----------
        Radius: float
        V: TopoDS_Vertex

        Returns
        -------
        None
        Initializes the vector on the point of parameter w.

        Parameters
        ----------
        UandR: gp_XY
        IinC: int

        Returns
        -------
        None
        Initializes the constant vector on all spine.

        Parameters
        ----------
        Radius: float

        Returns
        -------
        None
        Initializes the rule of evolution on all spine.

        Parameters
        ----------
        C: Law_Function
        IinC: int

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_FilSpine_SetRadius(self, *args)

    def UnSetRadius(self, *args) -> "void":
        r"""
        Resets the constant vector on edge e.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None
        Resets the vector on vertex v.

        Parameters
        ----------
        V: TopoDS_Vertex

        Returns
        -------
        None

        """
        return _ChFiDS.ChFiDS_FilSpine_UnSetRadius(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ChFiDS_FilSpine_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_FilSpine

# Register ChFiDS_FilSpine in _ChFiDS:
_ChFiDS.ChFiDS_FilSpine_swigregister(ChFiDS_FilSpine)

class ChFiDS_SecHArray1(ChFiDS_SecArray1, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _ChFiDS.ChFiDS_SecHArray1_swiginit(self, _ChFiDS.new_ChFiDS_SecHArray1(*args))

    def Array1(self) -> "ChFiDS_SecArray1 const &":
        return _ChFiDS.ChFiDS_SecHArray1_Array1(self)

    def ChangeArray1(self) -> "ChFiDS_SecArray1 &":
        return _ChFiDS.ChFiDS_SecHArray1_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_ChFiDS_SecHArray1_DownCast(t)

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_SecHArray1

# Register ChFiDS_SecHArray1 in _ChFiDS:
_ChFiDS.ChFiDS_SecHArray1_swigregister(ChFiDS_SecHArray1)

class ChFiDS_HData(ChFiDS_SequenceOfSurfData, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _ChFiDS.ChFiDS_HData_swiginit(self, _ChFiDS.new_ChFiDS_HData(*args))

    def Sequence(self) -> "ChFiDS_SequenceOfSurfData const &":
        return _ChFiDS.ChFiDS_HData_Sequence(self)

    def Append(self, *args) -> "void":
        return _ChFiDS.ChFiDS_HData_Append(self, *args)

    def ChangeSequence(self) -> "ChFiDS_SequenceOfSurfData &":
        return _ChFiDS.ChFiDS_HData_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_ChFiDS_HData_DownCast(t)

    __swig_destroy__ = _ChFiDS.delete_ChFiDS_HData

# Register ChFiDS_HData in _ChFiDS:
_ChFiDS.ChFiDS_HData_swigregister(ChFiDS_HData)





